% Generating stochastic fuel prices for each week within epoch (5 years):

% Using Geometrical Brownian Motion ("Random Walk") as stochastic process.

function Fuel_price_matrix = Epoch_weekly_stochastic_fuel_prices(Era,Era_generation)

% Number of weeks in 5 years:
Operating_time = 5*52;

Delta_t = 1; % time increment

    for k = 1:6
        
        % Prealocating space for storing the fuel price scenarios
        Fuel_scenario_HFO = zeros(1,Operating_time);
        Fuel_scenario_LNG = zeros(1,Operating_time);
        Fuel_scenario_HVO = zeros(1,Operating_time);
        Fuel_scenario_LBG = zeros(1,Operating_time);
        Fuel_scenario_E_diesel = zeros(1,Operating_time);
        Fuel_scenario_E_methane = zeros(1,Operating_time);
        Fuel_scenario_Hydrogen = zeros(1,Operating_time);
        Fuel_scenario_Ammonia = zeros(1,Operating_time);

        % Collecting starting price for each fuels in each epoch
        Fuel_price_start_HFO = Era_generation(k,1,Era);
        Fuel_price_start_LNG = Era_generation(k,3,Era);
        Fuel_price_start_HVO = Era_generation(k,4,Era);
        Fuel_price_start_LBG = Era_generation(k,6,Era);
        Fuel_price_start_E_diesel = Era_generation(k,8,Era);
        Fuel_price_start_E_methane = Era_generation(k,10,Era);
        Fuel_price_start_Hydrogen = Era_generation(k,12,Era);
        Fuel_price_start_Ammonia = Era_generation(k,15,Era);       

        % Pseudo random number generation
        dW = randn(8,Operating_time); % Wiener process (or Brownian motion). 
        
        % Set the fuel price in the beginning of each epoch
        Fuel_scenario_HFO(1) = Fuel_price_start_HFO; % Set the initial HFO fuel price.
        Fuel_scenario_LNG(1) = Fuel_price_start_LNG; % Set the intial LNG fuel price.
        Fuel_scenario_HVO(1) = Fuel_price_start_HVO; % Set the intial HVO fuel price.
        Fuel_scenario_LBG(1) = Fuel_price_start_LBG; % Set the intial LBG fuel price.
        Fuel_scenario_E_diesel(1) = Fuel_price_start_E_diesel; % Set the intial E-diesel fuel price.
        Fuel_scenario_E_methane(1) = Fuel_price_start_E_methane; % Set the intial E-methane fuel price.
        Fuel_scenario_Hydrogen(1) = Fuel_price_start_Hydrogen; % Set the intial hydrogen fuel price.
        Fuel_scenario_Ammonia(1) = Fuel_price_start_Ammonia; % Set the intial ammonia fuel price.

        
        % Generating the fuel price scenarios
        
        % Drift (Describing the long term movement)
        kappa_HFO = 0.01/52; % Drift describing the long term movement
        kappa_LNG = 0.01/52;
        kappa_HVO = 0.01/52;
        kappa_LBG = 0.01/52;
        kappa_E_diesel = 0.01/52;
        kappa_E_methane = 0.01/52;
        kappa_Hydrogen = 0.01/52;
        kappa_Ammonia = 0.01/52;
        
        % Price volatility
        sigma_HFO = 0.9/52;
        sigma_LNG = 0.9/52;
        sigma_HVO = sigma_LNG;
        sigma_LBG = sigma_LNG;
        sigma_E_diesel = sigma_LNG;
        sigma_E_methane = sigma_LNG;
        sigma_Hydrogen = sigma_LNG;
        sigma_Ammonia = sigma_LNG;
        
        
        % Using Geometrical Brownian Motion as stchastic process.
        for i = 2:Operating_time
            dFt1 = (kappa_HFO*Fuel_scenario_HFO(i-1)*Delta_t) + (Fuel_scenario_HFO(i-1)*sigma_HFO*dW(1,i));
            Fuel_scenario_HFO(i) = Fuel_scenario_HFO(i-1) + dFt1;
        end
        
        for i = 2:Operating_time
            dFt2 = (kappa_LNG*Fuel_scenario_LNG(i-1)*Delta_t) + (Fuel_scenario_LNG(i-1)*sigma_LNG*dW(2,i));
            Fuel_scenario_LNG(i) = Fuel_scenario_LNG(i-1) + dFt2;
        end
        
        for i = 2:Operating_time
            dFt3 = (kappa_HVO*Fuel_scenario_HVO(i-1)*Delta_t) + (Fuel_scenario_HVO(i-1)*sigma_HVO*dW(3,i));
            Fuel_scenario_HVO(i) = Fuel_scenario_HVO(i-1) + dFt3;
        end
        
        for i = 2:Operating_time
            dFt4 = (kappa_LBG*Fuel_scenario_LBG(i-1)*Delta_t) + (Fuel_scenario_LBG(i-1)*sigma_LBG*dW(4,i));
            Fuel_scenario_LBG(i) = Fuel_scenario_LBG(i-1) + dFt4;
        end
        
        for i = 2:Operating_time
            dFt5 = (kappa_E_diesel*Fuel_scenario_E_diesel(i-1)*Delta_t) + (Fuel_scenario_E_diesel(i-1)*sigma_E_diesel*dW(5,i));
            Fuel_scenario_E_diesel(i) = Fuel_scenario_E_diesel(i-1) + dFt5;
        end
        
        for i = 2:Operating_time
            dFt6 = (kappa_E_methane*Fuel_scenario_E_methane(i-1)*Delta_t) + (Fuel_scenario_E_methane(i-1)*sigma_E_methane*dW(6,i));
            Fuel_scenario_E_methane(i) = Fuel_scenario_E_methane(i-1) + dFt6;
        end
        
        for i = 2:Operating_time
            dFt7 = (kappa_Hydrogen*Fuel_scenario_Hydrogen(i-1)*Delta_t) + (Fuel_scenario_Hydrogen(i-1)*sigma_Hydrogen*dW(7,i));
            Fuel_scenario_Hydrogen(i) = Fuel_scenario_Hydrogen(i-1) + dFt7;
        end
        
        for i = 2:Operating_time
            dFt8 = (kappa_Ammonia*Fuel_scenario_Ammonia(i-1)*Delta_t) + (Fuel_scenario_Ammonia(i-1)*sigma_Ammonia*dW(7,i));
            Fuel_scenario_Ammonia(i) = Fuel_scenario_Ammonia(i-1) + dFt8;
        end
        
        HFO(k,:) = Fuel_scenario_HFO;
        LNG(k,:) = Fuel_scenario_LNG;
        HVO(k,:) = Fuel_scenario_HVO;
        LBG(k,:) = Fuel_scenario_LBG;
        E_diesel(k,:) = Fuel_scenario_E_diesel;
        E_methane(k,:) = Fuel_scenario_E_methane;
        Hydrogen(k,:) = Fuel_scenario_Hydrogen;
        Ammonia(k,:) = Fuel_scenario_Ammonia;

    end
    
    % Creating a price vector for the different fuels
    HFO_vector = [HFO(1,:) HFO(2,:) HFO(3,:) HFO(4,:) HFO(5,:) HFO(6,:)];
    LNG_vector = [LNG(1,:) LNG(2,:) LNG(3,:) LNG(4,:) LNG(5,:) LNG(6,:)];
    HVO_vector = [HVO(1,:) HVO(2,:) HVO(3,:) HVO(4,:) HVO(5,:) HVO(6,:)];
    LBG_vector = [LBG(1,:) LBG(2,:) LBG(3,:) LBG(4,:) LBG(5,:) LBG(6,:)];
    E_diesel_vector = [E_diesel(1,:) E_diesel(2,:) E_diesel(3,:) E_diesel(4,:) E_diesel(5,:) E_diesel(6,:)];
    E_methane_vector = [E_methane(1,:) E_methane(2,:) E_methane(3,:) E_methane(4,:) E_methane(5,:) E_methane(6,:)];
    Hydrogen_vector = [Hydrogen(1,:) Hydrogen(2,:) Hydrogen(3,:) Hydrogen(4,:) Hydrogen(5,:) Hydrogen(6,:)];
    Ammonia_vector = [Ammonia(1,:) Ammonia(2,:) Ammonia(3,:) Ammonia(4,:) Ammonia(5,:) Ammonia(6,:)];
    
    % Creating a fuel price matrix containing all of the fuels
    Fuel_price_matrix = [HFO_vector; LNG_vector; HVO_vector; LBG_vector; E_diesel_vector; E_methane_vector; Hydrogen_vector; Ammonia_vector]; 

% Use this if you want to plot the fuel price development:
    
% figure(1);    
% hold on
% plot(HFO_vector)
% plot(LNG_vector)
% plot(HVO_vector)
% plot(LBG_vector)
% plot(E_diesel_vector)
% plot(E_methane_vector)
% %plot(Hydrogen_vector)
% plot(Ammonia_vector)
% set(gcf,'color','w');
% legend('HFO fuel price','LNG fuel price','HVO fuel price','LBG fuel price','E-diesel fuel price','E-methane fuel price','Ammonia fuel price')
% title('Stochastic fuel price development within each epoch')
% xlabel('Weeks over 30 years')
% ylabel('Fuel price [USD/Tonn]')
% hold off                  
                     
end