clear all;
clc;

% Input data: 

%% Simulation parameters
Build_time = 2; %[Years] Construction time of the cruise ship
Operating_time = 30; %[Years] Operating time of the cruise ship

Total_lifecycle = Build_time + Operating_time; %[Years] Total lifecycle of the cruise ship


%% Economic parameters
d_r = 0.05; %[%] Discount rate 

t_loan_newbuild = Operating_time; %[Years] Down-payment time of the newbuild loan  

% Loss in revenue, due to local zero-emission zone:
Revenue_time_loss = 0.2; %[%]

%% Economy:

% CAPEX: (The total price of the new-build, as well as loans, interests and other financial costs related to the construction of the vessel).
% OPEX: (Day-to-day costs, mainly consisting of fees, repairs and maintenance and crewing). 
% Included locally
% VOYEX: (Expenditures unique to the voyage, as fuel cost, port and transit fees and pilot fee).

% Ship design parameters: 

% All costs in USD.

%                                          Standard ship    Dual-fuel ship      Ammonia ready ship
%                                                           
% Ship design (number):                    1                2                   3                                  
% CAPEX (newbuild) [USD]:                  1000000000       1012000000          1006000000
% CAPEX (Ammonia retrofit) [USD]:          0                0                   2000000
% CAPEX (hydrogen retrofit) [USD]:         0                0                   0
% Retrofit:                                0                0                   0
% Shipyard:                                0                0                   0 
% Hydrogen:                                0                0                   0

Ship_matrix = [1 2 3;
               1000000000 1012000000 1006000000;
               0 0 2000000;
               0 0 0;
               0 0 0;
               0 0 0;
               0 0 0];
           
Num_ship_design = 3; 

% Baseline: Zero-emission (95%): HVO, E-diesel (Only liquid fuels).
% Dual-fuel: Zero-emission (95%): HVO, LBG, E-methane, E-diesel (both liquid and gas).
% Ammonia ready: Zero-emission (95%): Retrofit to Ammonia.  

%% Epoch variables

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fueltypes + Fuel availability + Technology maturity
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Epoch variables                       Range       Step    Nr. of 
%                                       [min-max]   length  steps
% HFO price [USD/tonn]:                 200-700     50      11
% HFO availability:                     0-1         1       2                    
% LNG price [USD/tonn]:                 200-700     50      11           
% HVO price [USD/tonn]:                 800-4000    50      65
% HVO availability:                     0-1         1       2   
% LBG price [USD/tonn]:                 1100-4800   100     38
% LBG availability:                     0-1         1       2                     
% E-diesel price [USD/tonn]:            3500-9000   100     56          
% E-diesel availability:                0-1         1       2                
% E-methane price [USD/tonn]:           2300-6000   100     38    
% E-methane availability:               0-1         1       2               
% Hydrogen price [USD/tonn]:            -           -       -           
% Hydrogen technology maturity:         -           -       -
% Hydrogen availability:                -           -       -
% Ammonia price [USD/tonn]:             400-1700    50      26       
% Ammonia technology maturity:          0-1         1       2
% Ammonia availability:                 0-1         1       2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Environmental regulations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Local zero emission zone (95%):       0-1         1       2
% Global zero emission (95%):           0-1         1       2
% Local zero emission zone (100%):      -           -       -    
% Global zero emission (100%):          -           -       -
% Local CO2 tax [USD/tonn CO2]:         50-200      50      4
% Global CO2 tax [USD/tonn CO2]:        50-250      50      5
% Ports introduced EPI:                 0.25-1      0.25    4


% Creating era 1:          HFO  LNG     HVO     LBG     E-die    E-meth   hydrogen     Ammonia | Lo Glo Lo Glo Lo  Glo  EPI 
%                        pr  av  pr   pr  av  pr   av  pr   av  pr   av   pr  tec av  pr tec av| 95 95 100 100 CO2 CO2  %
Era_generation(:,:,1) = [400  1  300  900  0  1000  0  5600  0  3800  0   0   0   0   600  0  0  0  0   0   0  0   0    0.25;
                         400  1  300  950  0  1100  0  5200  0  3500  0   0   0   0   550  1  1  1  0   0   0  0   50   0.50; 
                         400  1  300  1000 1  1200  1  4800  0  3200  0   0   0   0   500  1  1  1  0   0   0  0   100  0.50;
                         400  1  300  1050 1  1300  1  4400  1  2900  1   0   0   0   450  1  1  1  1   0   0  0   150  0.75;
                         400  1  300  1100 1  1400  1  4000  1  2600  1   0   0   0   400  1  1  1  1   0   0  0   150  0.75;
                         400  1  300  1150 1  1500  1  3600  1  2300  1   0   0   0   400  1  1  1  1   0   0  0   150  0.75]
                     
                     
% Creating era 2:
%                          HFO  LNG     HVO     LBG     E-die    E-meth   hydrogen     Ammonia | Lo Glo Lo Glo Lo  Glo  EPI 
%                        pr  av  pr   pr  av  pr   av  pr   av  pr   av   pr  tec av  pr tec av| 95 95 100 100 CO2 CO2  %
Era_generation(:,:,2) = [400  1  300  900  0  1000  0  5600  0  3800  0   0   0   0   600  0  0  0  0   0   0  0   0    0.25;
                         400  1  300  950  0  1100  0  5200  0  3500  0   0   0   0   550  0  0  0  0   0   0  0   0    0.25;
                         400  1  300  1000 0  1200  0  4800  0  3200  0   0   0   0   500  1  0  1  0   0   0  0   0    0.25;
                         400  1  300  1050 1  1300  1  4400  0  2900  0   0   0   0   450  1  1  1  0   0   0  0   50   0.25;
                         400  1  300  1100 1  1400  1  4000  1  2600  1   0   0   0   400  1  1  1  0   0   0  0   50   0.25;
                         400  1  300  1150 1  1500  1  3600  1  2300  1   0   0   0   400  1  1  1  1   0   0  0   50   0.25]

% Creating era 3:
%                          HFO  LNG     HVO     LBG     E-die    E-meth   hydrogen     Ammonia | Lo Glo Lo Glo Lo  Glo  EPI 
%                        pr  av  pr   pr  av  pr   av  pr   av  pr   av   pr  tec av  pr tec av| 95 95 100 100 CO2 CO2  %
Era_generation(:,:,3) = [400  1  300  900  0  1000  0  5600  0  3800  0   0   0   0   600  0  0  0  0   0   0  100 0    0.25;
                         400  1  300  950  1  1100  1  5200  0  3500  0   0   0   0   550  1  1  1  0   0   0  0   150  0.50;
                         400  1  300  1000 1  1200  1  4800  1  3200  1   0   0   0   500  1  1  1  0   0   0  0   200  0.50;
                         400  1  300  1050 1  1300  1  4400  1  2900  1   0   0   0   450  1  1  1  1   0   0  0   200  0.75;
                         400  1  300  1100 1  1400  1  4000  1  2600  1   0   0   0   400  1  1  1  1   0   0  0   250  0.75;
                         400  0  300  1150 1  1500  1  3600  1  2300  1   0   0   0   400  1  1  1  1   0   0  0   250  0.75]                    

% Creating era 4: 
%                          HFO  LNG     HVO      LBG     E-die    E-meth   hydrogen     Ammonia | Lo Glo Lo Glo Lo  Glo  EPI 
%                        pr  av  pr   pr   av  pr   av  pr   av  pr   av   pr  tec av  pr tec av| 95 95 100 100 CO2 CO2  %
Era_generation(:,:,4) = [700  1  600  1000  0  1300  0  8900  0  6000  0   0   0   0   900  0  0  0  0   0   0  100 0    0.25;
                         700  1  600  1500  1  1800  1  8200  0  5500  0   0   0   0   850  1  1  1  0   0   0  0   150  0.50;
                         700  1  600  2000  1  2300  1  7500  1  5000  1   0   0   0   800  1  1  1  0   0   0  0   200  0.50;
                         700  1  600  2500  1  2800  1  6800  1  4500  1   0   0   0   750  1  1  1  1   0   0  0   200  0.75;
                         700  1  600  3000  1  3300  1  6100  1  4000  1   0   0   0   700  1  1  1  1   0   0  0   250  0.75;
                         700  0  600  3500  1  3800  1  5400  1  3500  1   0   0   0   650  1  1  1  1   0   0  0   250  0.75]                    
                                         
Num_eras = 4;

%% Functions: 
% (Note: It can be to heavy for the computer to run both Result_1 and
% Result_2 at the same time. Then if this is the case use percentage signe
% infront of one of them, and run them separatley). 

  Result_1 = Simulation_1(Total_lifecycle, Operating_time, Build_time, t_loan_newbuild, d_r, Ship_matrix, Num_ship_design, Era_generation, ...
      Num_eras, Revenue_time_loss)
 
  Result_2 = Simulation_2(Total_lifecycle, Operating_time, Build_time, t_loan_newbuild, d_r, Ship_matrix, Num_ship_design, Era_generation, ...
      Num_eras, Revenue_time_loss) 
 