% Calculating the OPEX

% OPEX: (Day-to-day costs, mainly consisting of fees, repairs and maintenance and crewing). 

function OPEX_calculation = OPEX(i,j,Ship_design,Retrofit,Hydrogen)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OPEX = Cost of crew + crew training + insurance + maintenance costs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

OPEX_HFO = 1700000; % [USD/year], yearly OPEX cost HFO fuelled ship
OPEX_LNG = 2800000; % [USD/year], yearly OPEX cost LNG fuelles ship
OPEX_ammonia = 3000000; % [USD/year], yearly OPEX cost ammonia fuelled ship
OPEX_hydrogen = 0; % [USD/year], yearly OPEX cost hydrogen fuelled ship

% OPEX cost for cell replacement in the fuel cell system after every 5 years. 
OPEX_hydrogen_5y = 0; %[USD/5 years], assumed to be 50% of the intial fuel cell CAPEX. 
Decrease_rate = 0; %[%] The price of PEMFC are predicted to decrease with a rate of 42% for each 5 years period.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ship design 1 (Baseline cruise ship design):
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    if Ship_design == 1
                
        if Retrofit == 2
            % Adding 5 years stack replacement of cells in the fuel cell
            if (i == 2 && j == 1 && Hydrogen == 1) || (i == 3 && j == 1 && Hydrogen == 1) || (i == 4 && j == 1 && Hydrogen == 1)...
                || (i == 5 && j == 1 && Hydrogen == 1) || (i == 6 && j == 1 && Hydrogen == 1)
                if i == 3 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + OPEX_hydrogen_5y;
                elseif i == 4 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate));
                elseif i == 5 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate)*(1-Decrease_rate));
                elseif i == 6 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate)*(1-Decrease_rate)*(1-Decrease_rate));
                end
            else 
                OPEX_calculation = OPEX_hydrogen;
            end
            Hydrogen = 0;
        else
            OPEX_calculation = OPEX_HFO;
        end
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ship design 2 (Dual fuel cruise ship design):
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%        
        
    elseif Ship_design == 2
        
        if Retrofit == 2
           % Adding 5 years stack replacement of cells in the fuel cell
            if (i == 2 && j == 1 && Hydrogen == 1) || (i == 3 && j == 1 && Hydrogen == 1) || (i == 4 && j == 1 && Hydrogen == 1)...
                || (i == 5 && j == 1 && Hydrogen == 1) || (i == 6 && j == 1 && Hydrogen == 1)
                if i == 3 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + OPEX_hydrogen_5y;
                elseif i == 4 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate));
                elseif i == 5 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate)*(1-Decrease_rate));
                elseif i == 6 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate)*(1-Decrease_rate)*(1-Decrease_rate));
                end
            else 
                OPEX_calculation = OPEX_hydrogen;
            end
            Hydrogen = 0;
        else
            OPEX_calculation = OPEX_LNG;
        end    
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ship design 3 (Ammonia ready cruise ship design):
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    
    elseif Ship_design == 3
    
        % Adding OPEX for drydock
        if Retrofit == 1
            OPEX_calculation = OPEX_ammonia;
        elseif Retrofit == 2
            % Adding 5 years stack replacement of cells in the fuel cell
            if (i == 2 && j == 1 && Hydrogen == 1) || (i == 3 && j == 1 && Hydrogen == 1) || (i == 4 && j == 1 && Hydrogen == 1)...
                || (i == 5 && j == 1 && Hydrogen == 1) || (i == 6 && j == 1 && Hydrogen == 1)
                if i == 3 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + OPEX_hydrogen_5y;
                elseif i == 4 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate));
                elseif i == 5 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate)*(1-Decrease_rate));
                elseif i == 6 && j == 1 && Hydrogen == 1
                    OPEX_calculation = OPEX_hydrogen + (OPEX_hydrogen_5y*(1-Decrease_rate)*(1-Decrease_rate)*(1-Decrease_rate));
                end
            else 
                OPEX_calculation = OPEX_hydrogen;
            end
            Hydrogen = 0;
        else
            OPEX_calculation = OPEX_HFO;
        end
    end
end

