% Calculating the port cost (included in the VOYEX)

function Yearly_Port_cost = Port_cost(i,Era,Era_generation,EPI_score)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Yearly port cost = port cost(ports with EPI) + port cost(ports without EPI)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

GT = 130818; % Gross tonnage of Celebrity Edge
Total_num_passengers = 4238; % Passengers + crew 
Num_twentyfour = 1; % Number of 24-hours in port 

Num_yearly_port_calls = 287; % [Days], 365 - (52/2+52) % Between 6 days each week, and 5 days each week. 52 vs. 104. 

% Calculating port cost (Bergen port used as example):
%From NOK to USD (currency rate of 02.04.2020): 
NOK_to_USD = 1/10.4;

% Data collected from: https://bergenhavn.no/wp-content/uploads/2019/04/PRISLISTE-fra-01.05.2019_EN-1.pdf
Fairway_dues = 0.26*NOK_to_USD; % [USD/GT], GT: Gross tonnage
Quay_dues = 0.9*NOK_to_USD; % [USD/GT/24-hour]
Passenger_fee = 5*NOK_to_USD; % [USD/passenger]
ISPS = 17*NOK_to_USD; % [USD/passenger]

Total_port_cost = ((Fairway_dues*GT) + (Quay_dues*GT*Num_twentyfour) + (Passenger_fee*Total_num_passengers) + (ISPS*Total_num_passengers));

%Fraction of ports visited that have introduced EPI: 
EPI_ports = Era_generation(i,24,Era);

% Calculating the port cost for the different ship designs

   if EPI_score <= 30
       EPI_discount = (30-EPI_score)*5/100;
       Yearly_Port_cost = (Total_port_cost * (1+EPI_discount) * Num_yearly_port_calls * EPI_ports) + (Total_port_cost * Num_yearly_port_calls * (1-EPI_ports));
   elseif EPI_score > 30
       EPI_discount = -(30-EPI_score)/(4*EPI_score);
       Yearly_Port_cost = (Total_port_cost * (1-EPI_discount) * Num_yearly_port_calls * EPI_ports) + (Total_port_cost * Num_yearly_port_calls * (1-EPI_ports));
   end
        
end   

    
    
    
    
    
    
    
    
    