% Calculate the annual revenue. 

function Revenue_calculation = Revenue(i,j,Retrofit,Ship_design,Shipyard)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Revenue per year = Revenue [USD/passenger/day] * Days sailing [days/year] * Passenger capacity [passengers]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Revenue per. passenger in average:
Revenue_per_passenger = 250; %250 [USD/passenger/day]
Num_days_sailing = 365; % [Days/year]

% Loss in days due to drydocking:
Days_in_drydock = 14;
Time_drydock = (1-(Days_in_drydock/Num_days_sailing)); % [Percentage of total number of days sailing]

% Loss in days due to retrofit at shipyard for the Ammonia ready design:
Days_in_shipyard = 14;
Time_shipyard = (1-(Days_in_shipyard/Num_days_sailing)); % [Percentage of total number of days sailing]

% Assuming that each cabins are for 2 persons. (1450*2 = 2900, approx. 2918 which is the total passenger capacity)
% Loosing one cabin = loosing 2 persons in capacity. 
% (Total_num_cabins = 1450)
Total_num_passengers = 2918;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Loss in passenger capacity
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Ship design 1 (Baseline cruise ship):
Loss_cabin_d1_r2 = 100; % Number of cabins taken away after retrofit to hydrogen + fuel cell design. 
Loss_capacity_d1_r2 = 2*Loss_cabin_d1_r2; % Loss in passenger capacity after retrofit. 

% Ship design 2 (Dual fuel cruise ship):
Loss_cabin_d2_r2 = 100; % Number of cabins taken away after retrofit to hydrogen + fuel cell design.  
Loss_capacity_d2_r2 = 2*Loss_cabin_d2_r2; % Loss in passenger capacity after retrofit. 

% Ship design 3 (Ammonia ready cruise ship):
Loss_capacity_d3_r0 = 0; % Initially lost cabins?
Loss_cabin_d3_r1 = 0; % Number of cabins taken away after retrofit to ammonia design. 
Loss_capacity_d3_r1 = 2*Loss_cabin_d3_r1; % Loss in passenger capacity after retrofit. 
Loss_cabin_d3_r2 = 100; % Number of cabins taken away after retrofit to hydrogen + fuel cell design. 
Loss_capacity_d3_r2 = 2*Loss_cabin_d3_r2; % Loss in passenger capacity after retrofit.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% Ship design 1 (Baseline cruise ship)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

    if Ship_design == 1 

        if Retrofit == 0
            
            if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing; %[USD/year]
            end
    
        elseif Retrofit == 1
    
            if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing; %[USD/year]
            end
    
        elseif Retrofit == 2
            
            if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                    || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d1_r2)*Num_days_sailing*Time_shipyard; %[USD/year]
            elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d1_r2)*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d1_r2)*Num_days_sailing; %[USD/year]
            end
            Shipyard = 0;
        end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ship design 2 (Dual fuel cruise ship design)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
        
        
    elseif Ship_design == 2
        
        if Retrofit == 0
    
            if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing; %[USD/year]
            end
    
        elseif Retrofit == 1
            
            if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*Total_num_passengers*Num_days_sailing; %[USD/year]
            end
            
        elseif Retrofit == 2
            
            if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                    || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d2_r2)*Num_days_sailing*Time_shipyard; %[USD/year]
            elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d2_r2)*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d2_r2)*Num_days_sailing; %[USD/year]
            end
            Shipyard = 0;
        end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ship design 3 (Ammonia ready cruise ship design)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    elseif Ship_design == 3
  
        if Retrofit == 0
    
            if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r0)*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r0)*Num_days_sailing; %[USD/year]
            end
    
        elseif Retrofit == 1
            
            if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                    || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r1)*Num_days_sailing*Time_shipyard; %[USD/year]
            elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r1)*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r1)*Num_days_sailing; %[USD/year]
            end
            Shipyard = 0;
            
        elseif Retrofit == 2
            
            if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                    || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r2)*Num_days_sailing*Time_shipyard; %[USD/year]
            elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r2)*Num_days_sailing*Time_drydock; %[USD/year]
            else
                Revenue_calculation = Revenue_per_passenger*(Total_num_passengers-Loss_capacity_d3_r2)*Num_days_sailing; %[USD/year]
            end
            Shipyard = 0;
        end
    end
end


