% Monte Carlo Simulation of the performance of each design in each era

function Result_1 = Simulation_1(Total_lifecycle, Operating_time, Build_time, t_loan_newbuild, d_r, Ship_matrix, Num_ship_design, Era_generation, ...
    Num_eras, Revenue_time_loss)

tic;

% Number of simulations.
Num_sim = 2000;

% Prealocating a NPV matrix for the results from simulation of all ships
% designs. 
NPV_matrix_log = zeros(Num_eras,Num_sim,Num_ship_design);

    % Selecting the ship design
    for a = 1:Num_ship_design
        
        for Era = 1:Num_eras 

            for j = 1:Num_sim
                
                NPV_calculation = Cash_flow(a,j,Total_lifecycle, Operating_time, Build_time, t_loan_newbuild, d_r, Ship_matrix, Num_ship_design, ...
                    Era_generation, Num_eras, Revenue_time_loss, Era);
        
                % Save the results in the matrix for each ship design.
                NPV_matrix_log(Era,j,a) = NPV_calculation;
                
            end
        end
    end
    
    Result_1 = NPV_matrix_log;
    
    % Collecting the results for the baseline design
    Baseline_design_era1 = Result_1(1,:,1);
    Baseline_design_era2 = Result_1(2,:,1);
    Baseline_design_era3 = Result_1(3,:,1);
    Baseline_design_era4 = Result_1(4,:,1);
    
    % Collecting the results for the dual fuel design
    Dual_fuel_design_era1 = Result_1(1,:,2);
    Dual_fuel_design_era2 = Result_1(2,:,2);
    Dual_fuel_design_era3 = Result_1(3,:,2);
    Dual_fuel_design_era4 = Result_1(4,:,2);
    
    % Collecting the results for the ammonia ready design
    Ammonia_ready_design_era1 = Result_1(1,:,3);
    Ammonia_ready_design_era2 = Result_1(2,:,3);
    Ammonia_ready_design_era3 = Result_1(3,:,3);
    Ammonia_ready_design_era4 = Result_1(4,:,3);
    
    % Calculating the mean NPV value
    % Baseline design
    ENPV_baseline_design_era1 = mean(Baseline_design_era1);
    ENPV_baseline_design_era2 = mean(Baseline_design_era2);
    ENPV_baseline_design_era3 = mean(Baseline_design_era3);
    ENPV_baseline_design_era4 = mean(Baseline_design_era4);
    % Dual fuel design
    ENPV_dual_fuel_design_era1 = mean(Dual_fuel_design_era1);
    ENPV_dual_fuel_design_era2 = mean(Dual_fuel_design_era2);
    ENPV_dual_fuel_design_era3 = mean(Dual_fuel_design_era3);
    ENPV_dual_fuel_design_era4 = mean(Dual_fuel_design_era4);
    % Ammonia ready design
    ENPV_ammonia_ready_design_era1 = mean(Ammonia_ready_design_era1);
    ENPV_ammonia_ready_design_era2 = mean(Ammonia_ready_design_era2);
    ENPV_ammonia_ready_design_era3 = mean(Ammonia_ready_design_era3);
    ENPV_ammonia_ready_design_era4 = mean(Ammonia_ready_design_era4);
    
    % Writing the ENPV results
    ENPV_results_1 = [ENPV_baseline_design_era1 ENPV_dual_fuel_design_era1 ENPV_ammonia_ready_design_era1;
                      ENPV_baseline_design_era2 ENPV_dual_fuel_design_era2 ENPV_ammonia_ready_design_era2;
                      ENPV_baseline_design_era3 ENPV_dual_fuel_design_era3 ENPV_ammonia_ready_design_era3;
                      ENPV_baseline_design_era4 ENPV_dual_fuel_design_era4 ENPV_ammonia_ready_design_era4]
    
    % Writing the "Value of flexibility"
    Value_flexibility_1 = [ENPV_results_1(1,2)-ENPV_results_1(1,1) ENPV_results_1(1,3)-ENPV_results_1(1,1);
                           ENPV_results_1(2,2)-ENPV_results_1(2,1) ENPV_results_1(2,3)-ENPV_results_1(2,1);
                           ENPV_results_1(3,2)-ENPV_results_1(3,1) ENPV_results_1(3,3)-ENPV_results_1(3,1);
                           ENPV_results_1(4,2)-ENPV_results_1(4,1) ENPV_results_1(4,3)-ENPV_results_1(4,1)]

                       
% Creating a cumulative distribution plot of the simulated NPV values    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% Baseline design and dual fuel design:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1)
cdfplot(Baseline_design_era1);
hold on
cdfplot(Dual_fuel_design_era1);
a = cdfplot(ENPV_baseline_design_era1);
set(a,'color','b','LineStyle','--')
b = cdfplot(ENPV_dual_fuel_design_era1);
set(b,'color','r','LineStyle','--')
legend('Baseline design','Dual fuel design')
title('[Era 1] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(2)
cdfplot(Baseline_design_era2);
hold on
cdfplot(Dual_fuel_design_era2);
a = cdfplot(ENPV_baseline_design_era2);
set(a,'color','b','LineStyle','--')
b = cdfplot(ENPV_dual_fuel_design_era2);
set(b,'color','r','LineStyle','--')
legend('Baseline design','Dual fuel design')
title('[Era 2] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(3)
cdfplot(Baseline_design_era3);
hold on
cdfplot(Dual_fuel_design_era3);
a = cdfplot(ENPV_baseline_design_era3);
set(a,'color','b','LineStyle','--')
b = cdfplot(ENPV_dual_fuel_design_era3);
set(b,'color','r','LineStyle','--')
legend('Baseline design','Dual fuel design')
title('[Era 3] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(4)
cdfplot(Baseline_design_era4);
hold on
cdfplot(Dual_fuel_design_era4);
a = cdfplot(ENPV_baseline_design_era4);
set(a,'color','b','LineStyle','--')
b = cdfplot(ENPV_dual_fuel_design_era4);
set(b,'color','r','LineStyle','--')
legend('Baseline design','Dual fuel design')
title('[Era 4] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% Baseline design and ammonia ready design:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(5)
cdfplot(Baseline_design_era1);
hold on
cdfplot(Ammonia_ready_design_era1);
c = cdfplot(ENPV_baseline_design_era1);
set(c,'color','b','LineStyle','--')
d = cdfplot(ENPV_ammonia_ready_design_era1);
set(d,'color','r','LineStyle','--')
legend('Baseline design','Ammonia ready design')
title('[Era 1] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(6)
cdfplot(Baseline_design_era2);
hold on
cdfplot(Ammonia_ready_design_era2);
c = cdfplot(ENPV_baseline_design_era2);
set(c,'color','b','LineStyle','--')
d = cdfplot(ENPV_ammonia_ready_design_era2);
set(d,'color','r','LineStyle','--')
legend('Baseline design','Ammonia ready design')
title('[Era 2] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(7)
cdfplot(Baseline_design_era3);
hold on
cdfplot(Ammonia_ready_design_era3);
c = cdfplot(ENPV_baseline_design_era3);
set(c,'color','b','LineStyle','--')
d = cdfplot(ENPV_ammonia_ready_design_era3);
set(d,'color','r','LineStyle','--')
legend('Baseline design','Ammonia ready design')
title('[Era 3] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(8)
cdfplot(Baseline_design_era4);
hold on
cdfplot(Ammonia_ready_design_era4);
c = cdfplot(ENPV_baseline_design_era4);
set(c,'color','b','LineStyle','--')
d = cdfplot(ENPV_ammonia_ready_design_era4);
set(d,'color','r','LineStyle','--')
legend('Baseline design','Ammonia ready design')
title('[Era 4] Cumulative NPV Distribution');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

toc;

end
