% Monte Carlos simulation of the performance for each cruise ship designs over eras. 

function Result_2 = Simulation_2(Total_lifecycle, Operating_time, Build_time, t_loan_newbuild, d_r, Ship_matrix, Num_ship_design, Era_generation, ...
    Num_eras, Revenue_time_loss)

tic;

% Number of simulations.
Num_sim = 2000; 

% Prealocating a NPV matrix for the results from simulation of all ship
% designs. 
NPV_matrix_log = zeros(Num_ship_design,Num_sim);

% Selecting the ship design 
for a = 1:Num_ship_design

    for j = 1:Num_sim
        
        % Selecting the Era randomly: (Here the eras are expected to occure
        % with the same probability)
        rand_num = rand();
        if rand_num <= 0.25
        Era = 1;
        elseif rand_num > 0.25 && rand_num <= 0.50
        Era = 2;
        elseif rand_num > 0.5 && rand_num <= 0.75
        Era = 3;
        elseif rand_num > 0.75 && rand_num <= 1
        Era = 4;
        end
        
        % Calculate the NPV for the ship design in the randonly selected
        % era.
        NPV_calculation = Cash_flow(a,j,Total_lifecycle, Operating_time, Build_time, t_loan_newbuild, d_r, Ship_matrix, Num_ship_design, Era_generation, ...
    Num_eras, Revenue_time_loss, Era);
        
        % Save the results in the matrix for each ship design.
        NPV_matrix_log(a,j) = NPV_calculation;
        
    end
end

Result_2 = NPV_matrix_log;

% Collect the NPV results for each design
Baseline_design = Result_2(1,:);
Dual_fuel_design = Result_2(2,:);
Ammonia_ready_design = Result_2(3,:);

% Calculating the mean NPV value
ENPV_baseline_design = mean(Baseline_design);
ENPV_dual_fuel_design = mean(Dual_fuel_design);
ENPV_ammonia_ready_design = mean(Ammonia_ready_design);

% Writing the ENPV for the cruise ship designs
ENPV_results_2 = [ENPV_baseline_design ENPV_dual_fuel_design ENPV_ammonia_ready_design]

% Writing the "Value of flexibility"
Value_flexibility_2 = [ENPV_results_2(1,2)-ENPV_results_2(1,1) ENPV_results_2(1,3)-ENPV_results_2(1,1)] 

% Creating a cumulative distribution plot of the simulated NPV values
figure(1)
cdfplot(Baseline_design);
hold on
cdfplot(Dual_fuel_design);
a = cdfplot(ENPV_baseline_design);
set(a,'color','b','LineStyle','--')
b = cdfplot(ENPV_dual_fuel_design);
set(b,'color','r','LineStyle','--')
legend('Baseline design','Dual fuel design')
title('Cumulative NPV Distribution (All eras)');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

figure(2)
cdfplot(Baseline_design);
hold on
cdfplot(Ammonia_ready_design);
c = cdfplot(ENPV_baseline_design);
set(c,'color','b','LineStyle','--')
d = cdfplot(ENPV_ammonia_ready_design);
set(d,'color','r','LineStyle','--')
legend('Baseline design','Ammonia ready design')
title('Cumulative NPV Distribution (All eras)');
xlabel('NPV [USD]');
ylabel('Cumulative Probability');
set(gcf,'color','w');
hold off

toc;

end


