% Calculating the VOYEX:

% VOYEX: Expenditures unique to the voyage, as fuel cost, port and transit fees and pilot fee.

function VOYEX_calculation = VOYEX(i,j,Era,Retrofit,Ship_design,Era_generation,Stochastic_fuel_price,Stochastic_fuel_price_weekly,Shipyard,Revenue_time_loss)

% Note: Will allways use stochastic fuel prices for the dual fuel design.

%%%%%%%%%%%%%%%%%%%%%%%%%%%
Stochastic_calculation = 1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Prealocating space for 7 days voyex calculation for dual fuel design
VOYEX_calculation_7d = zeros(1,52);

% Collecting data for stochastic fuel price generated for each week in each
% epoch:
Stochastic_fuel_weekly = Stochastic_fuel_price_weekly;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% VOYEX = Fuel cost + Port cost + CO2 tax
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Average_num_days_dock = 14;
Percentage_of_a_year_in_dock = Average_num_days_dock/365;
Timeloss_drydock = (1-Percentage_of_a_year_in_dock); %[Fraction of a year]

Average_num_days_shipyard = 14;
Percentage_of_a_year_in_shipyard = Average_num_days_shipyard/365;
Timeloss_shipyard = (1-Percentage_of_a_year_in_shipyard); %[Fraction of a year]

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CO2 tax (Local or global)
%%%%%%%%%%%%%%%%%%%%%%%%%%%

Time_local_tax_zone = 0.5; % Is 50% of the time in the local CO2 tax zone. 

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EPI   
%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Is calculated in its own funciton, Port_cost.m

HFO_EPI_score = 0;
LNG_EPI_score = 60;
HVO_EPI_score = 60;
LBG_EPI_score = 60;
E_diesel_EPI_score = 60;
E_methane_EPI_score = 60;
Hydrogen_EPI_score = 0;
Ammonia_EPI_score = 100;


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fuel specifications
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% HFO 
HFO_fuel_consumption = 27700; %[Tonn/year]
HFO_CO2_emissions = 88400; %[Tonn CO2/year]
% LNG
LNG_fuel_consumption = 23743; %[Tonn/year]
LNG_CO2_emissions = 88400*0.8; %[Tonn CO2/year] % HFO bare redusert med 20%
% HVO    
HVO_fuel_consumption = 31443; %[Tonn/year]
HVO_CO2_emissions = 88400*0.05; %[Tonn CO2/year] % 80% reduction compared to HFO (LCA)
% LBG
LBG_fuel_consumption = 23743; %[Tonn/year]
LBG_CO2_emissions = 88400*0.05; %[Tonn CO2/year] % 80% reduction compared to HFO (LCA)
% E-diesel    
E_diesel_fuel_consumption = 27056; %[Tonn/year]
E_diesel_CO2_emissions = 88400*0.05; %[Tonn CO2/year] % 0?
% E-methane
E_methane_fuel_consumption = 21153; %[Tonn/year]
E_methane_CO2_emissions = 88400*0.05; %[Tonn CO2/year] % 0?
% Hydrogen
Hydrogen_fuel_consumption = 4155; %[Tonn/year]
Hydrogen_CO2_emissions = 0; %[Tonn CO2/year] % 0?
% Ammonia
Ammonia_fuel_consumption = 64633; %[Tonn/year]
Ammonia_CO2_emissions = 0; %[CO2 Tonn/year] % 0?

%%%%%%%%%%%%%

    if i == 1 && j == 1
        t1 = 1;
    else
        t1 = ((j+((i-1)*5))-1)*52;
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % Ship design 1 (Baseline cruise ship)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

    if Stochastic_calculation == 1
        
        if Ship_design == 1

            if Retrofit == 0

                % Check if HFO is available. 
                if Era_generation(i,2,Era) == 1
                    Fuel_price =  Stochastic_fuel_weekly(1,t1);
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                elseif Era_generation(i,2,Era) == 0
                    Fuel_price = 10^30; % "Infinetly" high HFO fuel price, if it is not available. 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end

            % Fulfill a 95% GHG reduction
            elseif Retrofit == 1

                % Check if HVO is available. 
                if Era_generation(i,5,Era) == 1
                    HVO_price = Stochastic_fuel_weekly(3,t1);
                elseif Era_generation(i,5,Era) == 0 
                    HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                end

                % Check if E-diesel is available.
                if Era_generation(i,9,Era) == 1
                    E_diesel_price = Stochastic_fuel_weekly(5,t1);
                    Fuel_price = E_diesel_price; % [USD/tonn]
                    Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                    CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                    EPI_score = E_diesel_EPI_score; % [-]
                elseif Era_generation(i,9,Era) == 0 
                    E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.
                    Fuel_price = E_diesel_price; % [USD/tonn]
                    Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                    CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                    EPI_score = E_diesel_EPI_score; % [-]
                end

                % Select the cheapest one, if non of them is available,
                % then the "Cash_flow" calculation will avoid to do them,
                % as the cost of choosing this option will be "infinetly" high!
                if HVO_price <= E_diesel_price
                    Fuel_price = HVO_price; % [USD/tonn]
                    Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                    CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                    EPI_score = HVO_EPI_score; %[-]
                elseif E_diesel_price < HVO_price
                    Fuel_price = E_diesel_price; % [USD/tonn]
                    Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                    CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                    EPI_score = E_diesel_EPI_score; % [-]
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_1 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_1 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_1 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_1 = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_1 = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_1 = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end

                % Sailing the rest of the year using HFO:

                % Check if HFO is available. 
                if Era_generation(i,2,Era) == 1
                    Fuel_price =  Stochastic_fuel_weekly(1,t1);
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                elseif Era_generation(i,2,Era) == 0
                    Fuel_price = 10^30; % "Infinetly" high HFO fuel price, if it is not available. 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_2 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_2 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_2 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_2 = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_2 = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_2 = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end

                % Revenue_time_loss = Fraction of the year in the local zone.
                % Check that no global regulations occure during this epoch
                % and check if HFO was available.
                if (Era_generation(i,19,Era) == 0 && Era_generation(i,2,Era) == 1) || (Era_generation(i,21,Era) == 0 && Era_generation(i,2,Era) == 1) 
                    VOYEX_calculation = (VOYEX_calculation_1*Revenue_time_loss) + (VOYEX_calculation_2*(1-Revenue_time_loss));
                elseif (Era_generation(i,19,Era) == 1 && Era_generation(i,2,Era) == 0) || (Era_generation(i,21,Era) == 1 && Era_generation(i,2,Era) == 0) 
                    VOYEX_calculation = VOYEX_calculation_1;
                end

            % Fulfill a 100% GHG reduction
            elseif Retrofit == 2

                % Check if hydrogen is available and technologically mature.
                if Era_generation(i,14,Era) == 1 && Era_generation(i,13,Era) == 1
                   Fuel_price = Stochastic_fuel_weekly(7,t1);
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                else % If hydrogen is not available and/or technologically mature. 
                   Fuel_price = 10^30; % "infinetly" high fuel price. (Hydrogen as an option will then never be choosen by the model). 
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                end

                % Check shipyard
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1) ...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
            end

     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     % Ship design 2 (Dual fuel cruise ship)
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    

        elseif Ship_design == 2

            % The dual fuel ship can operate as normal.
            if Retrofit == 0

                % Select the cheapest option of LNG, HVO, LBG, E-diesel, E-methane. 
                    
                    for t = 1:52
                
                        % LNG is assumed to be available all over the world. 
                        % (2,(j+((i-1)*5)));
                        t_extra = 52 * ((j+((i-1)*5))-1);

                        LNG_price = Stochastic_fuel_weekly(2,t+t_extra);

                        % Check if HVO is available. 
                        if Era_generation(i,5,Era) == 1
                            HVO_price = Stochastic_fuel_weekly(3,t+t_extra);
                        elseif Era_generation(i,5,Era) == 0 
                            HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                        end

                        % Check if LBG is available. 
                        if Era_generation(i,7,Era) == 1
                            LBG_price = Stochastic_fuel_weekly(4,t+t_extra);
                        elseif Era_generation(i,7,Era) == 0 
                            LBG_price = 10^30; % Set LBG price "infinitely" large if is is not available.  
                        end

                        % Check if E-diesel is available. 
                        if Era_generation(i,9,Era) == 1
                            E_diesel_price = Stochastic_fuel_weekly(5,t+t_extra);
                        elseif Era_generation(i,9,Era) == 0 
                            E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.  
                        end

                        % Check if E-methane is available. 
                        if Era_generation(i,11,Era) == 1 
                            E_methane_price = Stochastic_fuel_weekly(6,t+t_extra);
                        elseif Era_generation(i,11,Era) == 0 
                            E_methane_price = 10^30; % Set E-methane price "infinitely" large if is is not available.  
                        end

                        % Collecting the fuel prices into a vector.
                        Fuel_price_vector = [LNG_price HVO_price LBG_price E_diesel_price E_methane_price];

                        % Select the cheapest fuel every year. 
                        if min(Fuel_price_vector) == Fuel_price_vector(1)
                            Fuel_price = LNG_price; % [USD/tonn]
                            Fuel_consumption = LNG_fuel_consumption; % [tonn/year]
                            CO2_emissions = LNG_CO2_emissions; %[tonn CO2/year]
                            EPI_score = LNG_EPI_score; %[-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(2)
                            Fuel_price = HVO_price; % [USD/tonn]
                            Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                            CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                            EPI_score = HVO_EPI_score; %[-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(3)
                            Fuel_price = LBG_price; % [USD/tonn]
                            Fuel_consumption = LBG_fuel_consumption; % [tonn/year]
                            CO2_emissions = LBG_CO2_emissions; %[tonn CO2/year]
                            EPI_score = LBG_EPI_score; %[-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(4)
                            Fuel_price = E_diesel_price; % [USD/tonn]
                            Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                            CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                            EPI_score = E_diesel_EPI_score; % [-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(5)
                            Fuel_price = E_methane_price; % [USD/tonn]
                            Fuel_consumption = E_methane_fuel_consumption; % [tonn/year]
                            CO2_emissions = E_methane_CO2_emissions; % [tonn CO2/year]
                            EPI_score = E_methane_EPI_score; % [-]
                        end



                        % Check for dry dock
                        if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                            % Local CO2 tax
                            if Era_generation(i,22,Era) > 0
                                CO2_tax = Era_generation(i,22,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)*Timeloss_drydock) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock; %[USD/year]
                            % Global CO2 tax
                            elseif Era_generation(i,23,Era) > 0
                                CO2_tax = Era_generation(i,23,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)*Timeloss_drydock) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock) + (Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock; %[USD/year]
                            elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)*Timeloss_drydock) + (Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock; %[USD/year]
                            end
                        else 
                            % Local CO2 tax
                            if Era_generation(i,22,Era) > 0
                                CO2_tax = Era_generation(i,22,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)) + (CO2_tax*(CO2_emissions/52)*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                            % Global CO2 tax
                            elseif Era_generation(i,23,Era) > 0
                                CO2_tax = Era_generation(i,23,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)) + (CO2_tax*(CO2_emissions/52)) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                            elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                            end
                        end
                
                    end
                    
                    VOYEX_calculation = sum(VOYEX_calculation_7d);
                
                

            % The dual fuel ship has to fulfill the 95% zero emission regulation.
            elseif Retrofit == 1

                % Here it cannot choose to use LNG. 
                
                for t = 1:52
                
                    t_extra = 52 * ((j+((i-1)*5))-1);

                    % Check if HVO is available. 
                    if Era_generation(i,5,Era) == 1
                        HVO_price = Stochastic_fuel_weekly(3,t+t_extra);
                    elseif Era_generation(i,5,Era) == 0 
                        HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                    end

                    % Check if LBG is available. 
                    if Era_generation(i,7,Era) == 1 
                        LBG_price = Stochastic_fuel_weekly(4,t+t_extra);
                    elseif Era_generation(i,7,Era) == 0 
                        LBG_price = 10^30; % Set LBG price "infinitely" large if is is not available.  
                    end

                    % Check if E-diesel is available. 
                    if Era_generation(i,9,Era) == 1
                        E_diesel_price = Stochastic_fuel_weekly(5,t+t_extra);
                    elseif Era_generation(i,9,Era) == 0 
                        E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.  
                    end

                    % Check if E-methane is available. 
                    if Era_generation(i,11,Era) == 1 
                        E_methane_price = Stochastic_fuel_weekly(6,t+t_extra);
                    elseif Era_generation(i,11,Era) == 0 
                        E_methane_price = 10^30; % Set E-methane price "infinitely" large if is is not available.  
                    end

                    % Collecting the fuel prices into a vector.
                    Fuel_price_vector = [HVO_price LBG_price E_diesel_price E_methane_price];

                    % Select the cheapest fuel every year.
                    % If non of them is available, then the model will
                    % automatically choose to not use the option of using any of
                    % them, as the cost will be very high, due to the "infinetly" 
                    % large fuel price.  
                    if min(Fuel_price_vector) == Fuel_price_vector(1)
                        Fuel_price = HVO_price; % [USD/tonn]
                        Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                        CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                        EPI_score = HVO_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(2)
                        Fuel_price = LBG_price; % [USD/tonn]
                        Fuel_consumption = LBG_fuel_consumption; % [tonn/year]
                        CO2_emissions = LBG_CO2_emissions; %[tonn CO2/year]
                        EPI_score = LBG_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(3)
                        Fuel_price = E_diesel_price; % [USD/tonn]
                        Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_diesel_EPI_score; % [-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(4)
                        Fuel_price = E_methane_price; % [USD/tonn]
                        Fuel_consumption = E_methane_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_methane_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_methane_EPI_score; % [-]
                    end

                    % Check for dry dock
                    if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock*Time_local_tax_zone) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + ((Port_cost(i,Era,Era_generation,EPI_score)/52*Timeloss_drydock)); %[USD/year]
                        end
                    else 
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*(CO2_emissions/52)*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*CO2_emissions/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        end
                    end
                end
                
                VOYEX_calculation_1 = sum(VOYEX_calculation_7d);
                
                % The rest of the year, LNG can also be used. 
                
                % Select the cheapest option of LNG, HVO, LBG, E-diesel, E-methane. 
                    
                    for t = 1:52
                
                        % LNG is assumed to be available all over the world. 
                        % (2,(j+((i-1)*5)));
                        t_extra = 52 * ((j+((i-1)*5))-1);

                        LNG_price = Stochastic_fuel_weekly(2,t+t_extra);

                        % Check if HVO is available. 
                        if Era_generation(i,5,Era) == 1
                            HVO_price = Stochastic_fuel_weekly(3,t+t_extra);
                        elseif Era_generation(i,5,Era) == 0 
                            HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                        end

                        % Check if LBG is available. 
                        if Era_generation(i,7,Era) == 1
                            LBG_price = Stochastic_fuel_weekly(4,t+t_extra);
                        elseif Era_generation(i,7,Era) == 0 
                            LBG_price = 10^30; % Set LBG price "infinitely" large if is is not available.  
                        end

                        % Check if E-diesel is available. 
                        if Era_generation(i,9,Era) == 1
                            E_diesel_price = Stochastic_fuel_weekly(5,t+t_extra);
                        elseif Era_generation(i,9,Era) == 0 
                            E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.  
                        end

                        % Check if E-methane is available. 
                        if Era_generation(i,11,Era) == 1 
                            E_methane_price = Stochastic_fuel_weekly(6,t+t_extra);
                        elseif Era_generation(i,11,Era) == 0 
                            E_methane_price = 10^30; % Set E-methane price "infinitely" large if is is not available.  
                        end

                        % Collecting the fuel prices into a vector.
                        Fuel_price_vector = [LNG_price HVO_price LBG_price E_diesel_price E_methane_price];

                        % Select the cheapest fuel every year. 
                        if min(Fuel_price_vector) == Fuel_price_vector(1)
                            Fuel_price = LNG_price; % [USD/tonn]
                            Fuel_consumption = LNG_fuel_consumption; % [tonn/year]
                            CO2_emissions = LNG_CO2_emissions; %[tonn CO2/year]
                            EPI_score = LNG_EPI_score; %[-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(2)
                            Fuel_price = HVO_price; % [USD/tonn]
                            Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                            CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                            EPI_score = HVO_EPI_score; %[-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(3)
                            Fuel_price = LBG_price; % [USD/tonn]
                            Fuel_consumption = LBG_fuel_consumption; % [tonn/year]
                            CO2_emissions = LBG_CO2_emissions; %[tonn CO2/year]
                            EPI_score = LBG_EPI_score; %[-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(4)
                            Fuel_price = E_diesel_price; % [USD/tonn]
                            Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                            CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                            EPI_score = E_diesel_EPI_score; % [-]
                        elseif min(Fuel_price_vector) == Fuel_price_vector(5)
                            Fuel_price = E_methane_price; % [USD/tonn]
                            Fuel_consumption = E_methane_fuel_consumption; % [tonn/year]
                            CO2_emissions = E_methane_CO2_emissions; % [tonn CO2/year]
                            EPI_score = E_methane_EPI_score; % [-]
                        end



                        % Check for dry dock
                        if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                            % Local CO2 tax
                            if Era_generation(i,22,Era) > 0
                                CO2_tax = Era_generation(i,22,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)*Timeloss_drydock) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock; %[USD/year]
                            % Global CO2 tax
                            elseif Era_generation(i,23,Era) > 0
                                CO2_tax = Era_generation(i,23,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)*Timeloss_drydock) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock) + (Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock; %[USD/year]
                            elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)*Timeloss_drydock) + (Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock; %[USD/year]
                            end
                        else 
                            % Local CO2 tax
                            if Era_generation(i,22,Era) > 0
                                CO2_tax = Era_generation(i,22,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)) + (CO2_tax*(CO2_emissions/52)*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                            % Global CO2 tax
                            elseif Era_generation(i,23,Era) > 0
                                CO2_tax = Era_generation(i,23,Era);
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)) + (CO2_tax*(CO2_emissions/52)) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                            elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                                VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52)) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                            end
                        end
                    end
                    
                VOYEX_calculation_2 = sum(VOYEX_calculation_7d);
                
                % Check if global regulation is introduced in this epoch.
                if Era_generation(i,19,Era) == 1 || Era_generation(i,21,Era) == 1
                    VOYEX_calculation = VOYEX_calculation_1;
                else
                    VOYEX_calculation = (VOYEX_calculation_1*Revenue_time_loss) + (VOYEX_calculation_2*(1-Revenue_time_loss));
                end
               
                
            % The dual fuel ship has to fulfill the 100% zero emission regulation.
            % - Retrofit to hydrogen + fuel cell. 
            elseif Retrofit == 2

                % Check if hydrogen is available and technologically mature.
                if Era_generation(i,14,Era) == 1 && Era_generation(i,13,Era) == 1
                   Fuel_price = Stochastic_fuel_weekly(7,t1);
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                else % If hydrogen is not available and/or technologically mature. 
                   Fuel_price = 10^30; % "infinetly" high fuel price. (Hydrogen as an option will then never be choosen by the model). 
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                end

                % Check for retrofit at a ship yard
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1) ...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
            end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % Ship design 3 (Ammonia ready cruise ship)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        elseif Ship_design == 3

            % Operate on HFO. 
            if Retrofit == 0

                % Check if HFO is available. 
                if Era_generation(i,2,Era) == 1
                    Fuel_price = Stochastic_fuel_weekly(1,t1);
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                elseif Era_generation(i,2,Era) == 0
                    Fuel_price = 10^30; % "Infinetly" high HFO fuel price, if it is not available. 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end

            % Need to fulfill a 95% zero emission regulation.        
            elseif Retrofit == 1

                % Assuming that we will allways retrofit to ammonia if possible.  

                % Check ammonia technology maturity and ammonia fuel availability.  
                if Era_generation(i,16,Era) == 1 && Era_generation(i,17,Era) == 1
                    Fuel_price = Stochastic_fuel_weekly(8,t1);
                    Fuel_consumption = Ammonia_fuel_consumption; % [tonn/year]
                    CO2_emissions = Ammonia_CO2_emissions; %[tonn CO2/year]
                    EPI_score = Ammonia_EPI_score; %[-]
                elseif Era_generation(i,16,Era) == 0 || Era_generation(i,17,Era) == 0
                    Fuel_price = 10^30; % "Infinitely" high fuel price if the ammonia technology and fuel is unavailable. 
                    Fuel_consumption = Ammonia_fuel_consumption; % [tonn/year]
                    CO2_emissions = Ammonia_CO2_emissions; %[tonn CO2/year]
                    EPI_score = Ammonia_EPI_score; %[-]
                end

                % Check for retrofit in a shipyard
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end


            % Need to fulfill a 100% zero emission regulation.      
            elseif Retrofit == 2

                % Check if hydrogen is available and technologically mature.
                if Era_generation(i,14,Era) == 1 && Era_generation(i,13,Era) == 1
                   Fuel_price = Stochastic_fuel_weekly(7,t1);
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                else % If hydrogen is not available and/or technologically mature. 
                   Fuel_price = 10^30; % "infinetly" high fuel price. (Hydrogen as an option will then never be choosen by the model). 
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                end

                % Check for retrofit in drydock
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
            end
        end
    
    
    else
    
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%        
% Non-stochastic fuel prises (Can be used if we want to use deterministc
% fuel prices for the baseline design and the ammonia ready design). 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % Ship design 1 (Baseline cruise ship)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
        
        
        if Ship_design == 1

            if Retrofit == 0

                % Check if HFO is available. 
                if Era_generation(i,2,Era) == 1
                    Fuel_price = Era_generation(i,1,Era); 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                elseif Era_generation(i,2,Era) == 0
                    Fuel_price = 10^30; % "Infinetly" high HFO fuel price, if it is not available. 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end

            % Fulfill a 95% GHG reduction
            elseif Retrofit == 1 

                % Check if HVO is available. 
                if Era_generation(i,5,Era) == 1 
                    HVO_price = Era_generation(i,4,Era);
                elseif Era_generation(i,5,Era) == 0 
                    HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                end

                % Check if E-diesel is available.
                if Era_generation(i,9,Era) == 1
                    E_diesel_price = Era_generation(i,8,Era);
                elseif Era_generation(i,9,Era) == 0 
                    E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.
                end

                % Select the cheapest one, if non of them is available,
                % then the "Cash_flow" calculation will avoid to do them,
                % as the cost of choosing this option will be "infinetly" high!
                if HVO_price <= E_diesel_price
                    Fuel_price = HVO_price; % [USD/tonn]
                    Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                    CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                    EPI_score = HVO_EPI_score; %[-]
                elseif E_diesel_price < HVO_price
                    Fuel_price = E_diesel_price; % [USD/tonn]
                    Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                    CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                    EPI_score = E_diesel_EPI_score; % [-]
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_1 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_1 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_1 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_1 = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_1 = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_1 = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
                
                % The rest of the year HFO can also be selected. 
                
                % Check if HFO is available. 
                if Era_generation(i,2,Era) == 1
                    Fuel_price = Era_generation(i,1,Era); 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                elseif Era_generation(i,2,Era) == 0
                    Fuel_price = 10^30; % "Infinetly" high HFO fuel price, if it is not available. 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_2 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_2 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_2 = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation_2 = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation_2 = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation_2 = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
                
                % Check if global regulation is introduced in this epoch
                % and if HFO was available.
                if (Era_generation(i,19,Era) == 0 && Era_generation(i,2,Era) == 1)|| (Era_generation(i,21,Era) == 0 && Era_generation(i,2,Era) == 1)
                    VOYEX_calculation = (VOYEX_calculation_1*Revenue_time_loss) + (VOYEX_calculation_2*(1-Revenue_time_loss));
                else
                    VOYEX_calculation = VOYEX_calculation_1;
                end
                

            % Fulfill a 100% GHG reduction
            elseif Retrofit == 2 

                % Check if hydrogen is available and technologically mature.
                if Era_generation(i,14,Era) == 1 && Era_generation(i,13,Era) == 1
                   Fuel_price = Era_generation(i,12,Era); % [USD/tonn]
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                else % If hydrogen is not available and/or technologically mature. 
                   Fuel_price = 10^30; % "infinetly" high fuel price. (Hydrogen as an option will then never be choosen by the model). 
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                end

                % Check for dry dock
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
            end

     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     % Ship design 2 (Dual fuel cruise ship)
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
     % Here stochastic fuel prices is included (stochastic fuel price wihin epochs)
     % in order to make it possible to value the switching option for the dual fuel ship. 
     %%%%
     
        elseif Ship_design == 2

            % The dual fuel ship can operate as normal.
            if Retrofit == 0

                % Select the cheapest option of LNG, HVO, LBG, E-diesel, E-methane. 
                
                for t = 1:52
                
                    t_extra = 52 * ((j+((i-1)*5))-1);

                    % LNG is assumed to be available all over the world. 
                    LNG_price = Stochastic_fuel_weekly(2,t+t_extra);

                    % Check if HVO is available. 
                    if Era_generation(i,5,Era) == 1 
                        HVO_price = Stochastic_fuel_weekly(3,t+t_extra);
                    elseif Era_generation(i,5,Era) == 0 
                        HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                    end

                    % Check if LBG is available. 
                    if Era_generation(i,7,Era) == 1 
                        LBG_price = Stochastic_fuel_weekly(4,t+t_extra);
                    elseif Era_generation(i,7,Era) == 0 
                        LBG_price = 10^30; % Set LBG price "infinitely" large if is is not available.  
                    end

                    % Check if E-diesel is available. 
                    if Era_generation(i,9,Era) == 1 
                        E_diesel_price = Stochastic_fuel_weekly(5,t+t_extra);
                    elseif Era_generation(i,9,Era) == 0 
                        E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.  
                    end

                    % Check if E-methane is available. 
                    if Era_generation(i,11,Era) == 1 
                        E_methane_price = Stochastic_fuel_weekly(6,t+t_extra);
                    elseif Era_generation(i,11,Era) == 0 
                        E_methane_price = 10^30; % Set E-methane price "infinitely" large if is is not available.  
                    end

                    % Collecting the fuel prices into a vector.
                    Fuel_price_vector = [LNG_price HVO_price LBG_price E_diesel_price E_methane_price];

                    % Select the cheapest fuel every year. 
                    if min(Fuel_price_vector) == Fuel_price_vector(1)
                        Fuel_price = LNG_price; % [USD/tonn]
                        Fuel_consumption = LNG_fuel_consumption; % [tonn/year]
                        CO2_emissions = LNG_CO2_emissions; %[tonn CO2/year]
                        EPI_score = LNG_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(2)
                        Fuel_price = HVO_price; % [USD/tonn]
                        Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                        CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                        EPI_score = HVO_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(3)
                        Fuel_price = LBG_price; % [USD/tonn]
                        Fuel_consumption = LBG_fuel_consumption; % [tonn/year]
                        CO2_emissions = LBG_CO2_emissions; %[tonn CO2/year]
                        EPI_score = LBG_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(4)
                        Fuel_price = E_diesel_price; % [USD/tonn]
                        Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_diesel_EPI_score; % [-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(5)
                        Fuel_price = E_methane_price; % [USD/tonn]
                        Fuel_consumption = E_methane_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_methane_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_methane_EPI_score; % [-]
                    end

                    % Check for dry dock
                    if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock*Time_local_tax_zone) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock) + ((Port_cost(i,Era,Era_generation,EPI_score)/52*Timeloss_drydock)); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        end
                    else 
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*(CO2_emissions/52)*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*CO2_emissions/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        end
                    end
                end
                
                VOYEX_calculation = sum(VOYEX_calculation_7d);

            % The dual fuel ship has to fulfill the 95% zero emission regulation.
            elseif Retrofit == 1

                % Here it cannot choose to use LNG. 
                
                for t = 1:52
                
                    t_extra = 52 * ((j+((i-1)*5))-1);

                    % Check if HVO is available. 
                    if Era_generation(i,5,Era) == 1 
                        HVO_price = Stochastic_fuel_weekly(3,t+t_extra);
                    elseif Era_generation(i,5,Era) == 0 
                        HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                    end

                    % Check if LBG is available. 
                    if Era_generation(i,7,Era) == 1 
                        LBG_price = Stochastic_fuel_weekly(4,t+t_extra);
                    elseif Era_generation(i,7,Era) == 0 
                        LBG_price = 10^30; % Set LBG price "infinitely" large if is is not available.  
                    end

                    % Check if E-diesel is available. 
                    if Era_generation(i,9,Era) == 1 
                        E_diesel_price = Stochastic_fuel_weekly(5,t+t_extra);
                    elseif Era_generation(i,9,Era) == 0 
                        E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.  
                    end

                    % Check if E-methane is available. 
                    if Era_generation(i,11,Era) == 1 
                        E_methane_price = Stochastic_fuel_weekly(6,t+t_extra);
                    elseif Era_generation(i,11,Era) == 0 
                        E_methane_price = 10^30; % Set E-methane price "infinitely" large if is is not available.  
                    end

                    % Collecting the fuel prices into a vector.
                    Fuel_price_vector = [HVO_price LBG_price E_diesel_price E_methane_price];

                    % Select the cheapest fuel every year.
                    % If non of them is available, then the model will
                    % automatically choose to not use the option of using any of
                    % them, as the cost will be very high, due to the "infinetly" 
                    % large fuel price.  
                    if min(Fuel_price_vector) == Fuel_price_vector(1)
                        Fuel_price = HVO_price; % [USD/tonn]
                        Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                        CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                        EPI_score = HVO_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(2)
                        Fuel_price = LBG_price; % [USD/tonn]
                        Fuel_consumption = LBG_fuel_consumption; % [tonn/year]
                        CO2_emissions = LBG_CO2_emissions; %[tonn CO2/year]
                        EPI_score = LBG_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(3)
                        Fuel_price = E_diesel_price; % [USD/tonn]
                        Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_diesel_EPI_score; % [-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(4)
                        Fuel_price = E_methane_price; % [USD/tonn]
                        Fuel_consumption = E_methane_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_methane_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_methane_EPI_score; % [-]
                    end

                    % Check for dry dock
                    if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock*Time_local_tax_zone) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        end
                    else 
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*(CO2_emissions/52)*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*CO2_emissions/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        end
                    end
                end
                
                VOYEX_calculation_1 = sum(VOYEX_calculation_7d);
                
                % The rest of the year LNG can also be selected.
            
                % Select the cheapest option of LNG, HVO, LBG, E-diesel, E-methane. 
                for t = 1:52
                
                    t_extra = 52 * ((j+((i-1)*5))-1);

                    % LNG is assumed to be available all over the world. 
                    LNG_price = Stochastic_fuel_weekly(2,t+t_extra);

                    % Check if HVO is available. 
                    if Era_generation(i,5,Era) == 1 
                        HVO_price = Stochastic_fuel_weekly(3,t+t_extra);
                    elseif Era_generation(i,5,Era) == 0 
                        HVO_price = 10^30; % Set HVO price "infinitely" large if is is not available.  
                    end

                    % Check if LBG is available. 
                    if Era_generation(i,7,Era) == 1 
                        LBG_price = Stochastic_fuel_weekly(4,t+t_extra);
                    elseif Era_generation(i,7,Era) == 0 
                        LBG_price = 10^30; % Set LBG price "infinitely" large if is is not available.  
                    end

                    % Check if E-diesel is available. 
                    if Era_generation(i,9,Era) == 1 
                        E_diesel_price = Stochastic_fuel_weekly(5,t+t_extra);
                    elseif Era_generation(i,9,Era) == 0 
                        E_diesel_price = 10^30; % Set E-diesel price "infinitely" large if is is not available.  
                    end

                    % Check if E-methane is available. 
                    if Era_generation(i,11,Era) == 1 
                        E_methane_price = Stochastic_fuel_weekly(6,t+t_extra);
                    elseif Era_generation(i,11,Era) == 0 
                        E_methane_price = 10^30; % Set E-methane price "infinitely" large if is is not available.  
                    end

                    % Collecting the fuel prices into a vector.
                    Fuel_price_vector = [LNG_price HVO_price LBG_price E_diesel_price E_methane_price];

                    % Select the cheapest fuel every year. 
                    if min(Fuel_price_vector) == Fuel_price_vector(1)
                        Fuel_price = LNG_price; % [USD/tonn]
                        Fuel_consumption = LNG_fuel_consumption; % [tonn/year]
                        CO2_emissions = LNG_CO2_emissions; %[tonn CO2/year]
                        EPI_score = LNG_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(2)
                        Fuel_price = HVO_price; % [USD/tonn]
                        Fuel_consumption = HVO_fuel_consumption; % [tonn/year]
                        CO2_emissions = HVO_CO2_emissions; %[tonn CO2/year]
                        EPI_score = HVO_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(3)
                        Fuel_price = LBG_price; % [USD/tonn]
                        Fuel_consumption = LBG_fuel_consumption; % [tonn/year]
                        CO2_emissions = LBG_CO2_emissions; %[tonn CO2/year]
                        EPI_score = LBG_EPI_score; %[-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(4)
                        Fuel_price = E_diesel_price; % [USD/tonn]
                        Fuel_consumption = E_diesel_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_diesel_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_diesel_EPI_score; % [-]
                    elseif min(Fuel_price_vector) == Fuel_price_vector(5)
                        Fuel_price = E_methane_price; % [USD/tonn]
                        Fuel_consumption = E_methane_fuel_consumption; % [tonn/year]
                        CO2_emissions = E_methane_CO2_emissions; % [tonn CO2/year]
                        EPI_score = E_methane_EPI_score; % [-]
                    end

                    % Check for dry dock
                    if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock*Time_local_tax_zone) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + (CO2_tax*(CO2_emissions/52)*Timeloss_drydock) + ((Port_cost(i,Era,Era_generation,EPI_score)/52*Timeloss_drydock)); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*(Fuel_consumption/52*Timeloss_drydock)) + ((Port_cost(i,Era,Era_generation,EPI_score)/52)*Timeloss_drydock); %[USD/year]
                        end
                    else 
                        % Local CO2 tax
                        if Era_generation(i,22,Era) > 0
                            CO2_tax = Era_generation(i,22,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*(CO2_emissions/52)*Time_local_tax_zone) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        % Global CO2 tax
                        elseif Era_generation(i,23,Era) > 0
                            CO2_tax = Era_generation(i,23,Era);
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (CO2_tax*CO2_emissions/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                            VOYEX_calculation_7d(t) = (Fuel_price*Fuel_consumption/52) + (Port_cost(i,Era,Era_generation,EPI_score)/52); %[USD/year]
                        end
                    end
                end
                
                VOYEX_calculation_2 = sum(VOYEX_calculation_7d);
                
                % Check if global regulation is introduced in this epoch.
                if Era_generation(i,19,Era) == 1 || Era_generation(i,21,Era) == 1
                    VOYEX_calculation = VOYEX_calculation_1;
                else
                    VOYEX_calculation = (VOYEX_calculation_1*Revenue_time_loss) + (VOYEX_calculation_2*(1-Revenue_time_loss));
                end

            % The dual fuel ship has to fulfill the 100% zero emission regulation.
            % - Retrofit to hydrogen + fuel cell. 
            elseif Retrofit == 2

                % Check if hydrogen is available and technologically mature.
                if Era_generation(i,14,Era) == 1 && Era_generation(i,13,Era) == 1
                   Fuel_price = Era_generation(i,12,Era); % [USD/tonn]
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                else % If hydrogen is not available and/or technologically mature. 
                   Fuel_price = 10^30; % "infinetly" high fuel price. (Hydrogen as an option will then never be choosen by the model). 
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                end

                % Check for retrofit at a shipyard
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                    % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end
            end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % Ship design 3 (Ammonia ready cruise ship)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        elseif Ship_design == 3

            % Operate on HFO. 
            if Retrofit == 0

                % Check if HFO is available. 
                if Era_generation(i,2,Era) == 1
                    Fuel_price = Era_generation(i,1,Era);
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                elseif Era_generation(i,2,Era) == 0
                    Fuel_price = 10^30; % "Infinetly" high HFO fuel price, if it is not available. 
                    Fuel_consumption = HFO_fuel_consumption;
                    CO2_emissions = HFO_CO2_emissions;
                    EPI_score = HFO_EPI_score;
                end

                % Check for dry dock
                if (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end

            % Need to fulfill a 95% zero emission regulation.        
            elseif Retrofit == 1

                % Assuming that we will allways retrofit to ammonia if possible.  

                % Check ammonia technology maturity and ammonia fuel availability.  
                if Era_generation(i,16,Era) == 1 && Era_generation(i,17,Era) == 1
                    Fuel_price = Era_generation(i,15,Era); % [USD/tonn]
                    Fuel_consumption = Ammonia_fuel_consumption; % [tonn/year]
                    CO2_emissions = Ammonia_CO2_emissions; %[tonn CO2/year]
                    EPI_score = Ammonia_EPI_score; %[-]
                elseif Era_generation(i,16,Era) == 0 || Era_generation(i,17,Era) == 0
                    Fuel_price = 10^30; % "Infinitely" high fuel price if the ammonia technology and fuel is unavailable. 
                    Fuel_consumption = Ammonia_fuel_consumption; % [tonn/year]
                    CO2_emissions = Ammonia_CO2_emissions; %[tonn CO2/year]
                    EPI_score = Ammonia_EPI_score; %[-]
                end

                % Check for retrofit at shipyard
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end


            % Need to fulfill a 100% zero emission regulation.      
            elseif Retrofit == 2

                % Check if hydrogen is available and technologically mature.
                if Era_generation(i,14,Era) == 1 && Era_generation(i,13,Era) == 1
                   Fuel_price = Era_generation(i,12,Era); % [USD/tonn]
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                else % If hydrogen is not available and/or technologically mature. 
                   Fuel_price = 10^30; % "infinetly" high fuel price. (Hydrogen as an option will then never be choosen by the model). 
                   Fuel_consumption = Hydrogen_fuel_consumption; % [tonn/year]
                   CO2_emissions = Hydrogen_CO2_emissions; % [tonn CO2/year]
                   EPI_score = Hydrogen_EPI_score; % [-]
                end

                % Check for retrofit at a shipyard
                if (j == 1 && i == 2 && Shipyard == 1) || (j == 1 && i == 3 && Shipyard == 1) || (j == 1 && i == 4 && Shipyard == 1)...
                        || (j == 1 && i == 5 && Shipyard == 1) || (j == 1 && i == 6 && Shipyard == 1)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + (CO2_tax*(CO2_emissions)*Timeloss_shipyard) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_shipyard)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_shipyard; %[USD/year]
                    end
                    Shipyard = 0;
                % Check for dry dock
                elseif (j == 1 && i == 2) || (j == 1 && i == 3) || (j == 1 && i == 4) || (j == 1 && i == 5) || (j == 1 && i == 6)
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + (CO2_tax*(CO2_emissions)*Timeloss_drydock) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*(Fuel_consumption*Timeloss_drydock)) + Port_cost(i,Era,Era_generation,EPI_score)*Timeloss_drydock; %[USD/year]
                    end
                else 
                    % Local CO2 tax
                    if Era_generation(i,22,Era) > 0
                        CO2_tax = Era_generation(i,22,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*(CO2_emissions)*Time_local_tax_zone) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    % Global CO2 tax
                    elseif Era_generation(i,23,Era) > 0
                        CO2_tax = Era_generation(i,23,Era);
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + (CO2_tax*CO2_emissions) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    elseif Era_generation(i,22,Era) == 0 && Era_generation(i,23,Era) == 0
                        VOYEX_calculation = (Fuel_price*Fuel_consumption) + Port_cost(i,Era,Era_generation,EPI_score); %[USD/year]
                    end
                end 
            end
        end
    end
end

